package jdk.internal.org.objectweb.asm.tree;

import jdk.internal.org.objectweb.asm.MethodVisitor;
import java.util.Iterator;
import java.util.List;

public class TryCatchBlockNode
{
    public LabelNode start;
    public LabelNode end;
    public LabelNode handler;
    public String type;
    public List<TypeAnnotationNode> visibleTypeAnnotations;
    public List<TypeAnnotationNode> invisibleTypeAnnotations;
    
    public TryCatchBlockNode(LabelNode start, LabelNode end, LabelNode handler, String type) {
        this.start = start;
        this.end = end;
        this.handler = handler;
        this.type = type;
    }
    
    public void updateIndex(int n) {
        int n2 = 0x42000000 | n << 8;
        if (this.visibleTypeAnnotations != null) {
            Iterator<TypeAnnotationNode> iterator = this.visibleTypeAnnotations.iterator();
            while (iterator.hasNext()) {
                ((TypeAnnotationNode)iterator.next()).typeRef = n2;
            }
        }
        if (this.invisibleTypeAnnotations != null) {
            Iterator<TypeAnnotationNode> iterator2 = this.invisibleTypeAnnotations.iterator();
            while (iterator2.hasNext()) {
                ((TypeAnnotationNode)iterator2.next()).typeRef = n2;
            }
        }
    }
    
    public void accept(MethodVisitor methodVisitor) {
        methodVisitor.visitTryCatchBlock(this.start.getLabel(), this.end.getLabel(), (this.handler == null) ? null : this.handler.getLabel(), this.type);
        for (int n = (this.visibleTypeAnnotations == null) ? 0 : this.visibleTypeAnnotations.size(), i = 0; i < n; ++i) {
            TypeAnnotationNode typeAnnotationNode = (TypeAnnotationNode)this.visibleTypeAnnotations.get(i);
            typeAnnotationNode.accept(methodVisitor.visitTryCatchAnnotation(typeAnnotationNode.typeRef, typeAnnotationNode.typePath, typeAnnotationNode.desc, true));
        }
        for (int n2 = (this.invisibleTypeAnnotations == null) ? 0 : this.invisibleTypeAnnotations.size(), j = 0; j < n2; ++j) {
            TypeAnnotationNode typeAnnotationNode2 = (TypeAnnotationNode)this.invisibleTypeAnnotations.get(j);
            typeAnnotationNode2.accept(methodVisitor.visitTryCatchAnnotation(typeAnnotationNode2.typeRef, typeAnnotationNode2.typePath, typeAnnotationNode2.desc, false));
        }
    }
}
